@@ -511,3 +511,32 @@ def interactivemode_flag(request):
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
+
+
+@pytest.fixture
+def reportportal_service(request):
+    "pytest service fixture for reportportal"
+    reportportal_pytest_service = None
+    try:
+        if request.config.getoption("--reportportal"):
+            reportportal_pytest_service = request.node.config.py_test_service
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+    return reportportal_pytest_service
+
+@pytest.fixture
+def test_env(request):
+    "pytest service fixture for set test environment"
+    test_env = "UAT"
+    try:
+        if request.config.getoption("--test_env"):
+            test_env = request.config.getoption("--test_env").lower()
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
+    return test_env
+
+
